#ifndef NT2_INCLUDE_FUNCTIONS_POLYSUB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYSUB_HPP_INCLUDED

#include <nt2/polynom/include/functions/polysub.hpp>

#endif
